@@ -16,10 +16,12 @@ static
 void tagstack_push(struct tagstack* tagstack, struct tagstack_entry);
 static 
 struct tagstack_entry tagstack_pop(struct tagstack* tagstack);
+INLINE
 static 
-struct tagstack_entry* tagstack_top(struct tagstack* tagstack);
+struct tagstack_entry* tagstack_top(const struct tagstack* tagstack);
+INLINE
 static 
-int tagstack_notempty(struct tagstack* tagstack);
+int tagstack_notempty(const struct tagstack* tagstack);
 
 #endif /* tagstack.h */
 
